@@ -2,7 +2,9 @@
 import io
 import pytest
 import re
+import uuid
 
+from collections import namedtuple
 from unittest import mock
 
 from toot import console, User, App, http
@@ -13,6 +15,8 @@ from tests.utils import MockResponse
 app = App('habunek.com', 'https://habunek.com', 'foo', 'bar')
 user = User('habunek.com', 'ivan@habunek.com', 'xxx')
 
+MockUuid = namedtuple("MockUuid", ["hex"])
+
 
 def uncolorize(text):
     """Remove ANSI color sequences from a string"""
@@ -25,8 +29,10 @@ def test_print_usage(capsys):
     assert "toot - a Mastodon CLI client" in out
 
 
+@mock.patch('uuid.uuid4')
 @mock.patch('toot.http.post')
-def test_post_defaults(mock_post, capsys):
+def test_post_defaults(mock_post, mock_uuid, capsys):
+    mock_uuid.return_value = MockUuid("rock-on")
     mock_post.return_value = MockResponse({
         'url': 'https://habunek.com/@ihabunek/1234567890'
     })
@@ -37,9 +43,10 @@ def test_post_defaults(mock_post, capsys):
         'status': 'Hello world',
         'visibility': 'public',
         'media_ids[]': None,
-        'sensitive': False,
+        'sensitive': "false",
         'spoiler_text': None,
-    })
+        'in_reply_to_id': None,
+    }, headers={"Idempotency-Key": "rock-on"})
 
     out, err = capsys.readouterr()
     assert 'Toot posted' in out
@@ -47,9 +54,17 @@ def test_post_defaults(mock_post, capsys):
     assert not err
 
 
+@mock.patch('uuid.uuid4')
 @mock.patch('toot.http.post')
-def test_post_with_options(mock_post, capsys):
-    args = ['Hello world', '--visibility', 'unlisted', '--sensitive', '--spoiler-text', 'Spoiler!']
+def test_post_with_options(mock_post, mock_uuid, capsys):
+    mock_uuid.return_value = MockUuid("up-the-irons")
+    args = [
+        'Hello world',
+        '--visibility', 'unlisted',
+        '--sensitive',
+        '--spoiler-text', 'Spoiler!',
+        '--reply-to', '123'
+    ]
 
     mock_post.return_value = MockResponse({
         'url': 'https://habunek.com/@ihabunek/1234567890'
@@ -61,9 +76,10 @@ def test_post_with_options(mock_post, capsys):
         'status': 'Hello world',
         'media_ids[]': None,
         'visibility': 'unlisted',
-        'sensitive': True,
+        'sensitive': "true",
         'spoiler_text': "Spoiler!",
-    })
+        'in_reply_to_id': 123,
+    }, headers={"Idempotency-Key": "up-the-irons"})
 
     out, err = capsys.readouterr()
     assert 'Toot posted' in out
@@ -91,6 +107,17 @@ def test_post_invalid_media(capsys):
     assert "can't open 'does_not_exist.jpg'" in err
 
 
+@mock.patch('toot.http.delete')
+def test_delete(mock_delete, capsys):
+    console.run_command(app, user, 'delete', ['12321'])
+
+    mock_delete.assert_called_once_with(app, user, '/api/v1/statuses/12321')
+
+    out, err = capsys.readouterr()
+    assert 'Status deleted' in out
+    assert not err
+
+
 @mock.patch('toot.http.get')
 def test_timeline(mock_get, monkeypatch, capsys):
     mock_get.return_value = MockResponse([{
