@@ -1,15 +1,19 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-from __future__ import print_function
 
 import re
+import socket
+import unicodedata
 
 from bs4 import BeautifulSoup
 
+from toot.exceptions import ConsoleError
+
 
 def get_text(html):
     """Converts html to text, strips all tags."""
-    return BeautifulSoup(html, "html.parser").get_text().replace('&apos;', "'")
+    text = BeautifulSoup(html, "html.parser").get_text().replace('&apos;', "'")
+
+    return unicodedata.normalize('NFKC', text)
 
 
 def parse_html(html):
@@ -43,3 +47,24 @@ def format_content(content):
             yield line
 
         first = False
+
+
+def domain_exists(name):
+    try:
+        socket.gethostbyname(name)
+        return True
+    except OSError:
+        return False
+
+
+def assert_domain_exists(domain):
+    if not domain_exists(domain):
+        raise ConsoleError("Domain {} not found".format(domain))
+
+
+def trunc(text, length):
+    """Trims text to given length, if trimmed appends ellipsis."""
+    if len(text) <= length:
+        return text
+
+    return text[:length - 1] + '…'
